import os
import subprocess
import json

from metaquantome.util.utils import BASE_DIR
from metaquantome.SampleGroups import SampleGroups


def run_viz(plottype, img, infile, strip=None,
            mode=None, meancol=None, nterms='5', target_rank=None, barcol=6,  # barplot
            textannot=None, fc_name=None, flip_fc=False, gosplit=False,  # volcano
            sinfo=None, filter_to_sig=False, alpha='0.05',  # heatmap
            calculate_sep=False,  # pca
            whichway=None, name=None, id=None, target_onto=None, # ft_dist
            width='5', height='5'):
    r_script_path = os.path.join(BASE_DIR, 'analysis', 'viz.R')
    FNULL = open(os.devnull, 'w')
    cmd = ['Rscript', '--vanilla', r_script_path, plottype, img, infile]
    if plottype == "bar":
        cmd += [mode, meancol, nterms, width, height, target_rank, barcol]
    elif plottype == "volcano":
        cmd += [str(textannot), fc_name, flip_fc, gosplit, width, height]
    elif plottype == "heatmap":
        samp_grps = SampleGroups(sinfo)
        all_intcols_str = ','.join(samp_grps.all_intcols)
        json_dump = json.dumps(samp_grps.sample_names)
        cmd += [all_intcols_str, json_dump, filter_to_sig, alpha, width, height, strip]
    elif plottype == "pca":
        samp_grps = SampleGroups(sinfo)
        all_intcols_str = ','.join(samp_grps.all_intcols)
        json_dump = json.dumps(samp_grps.sample_names)
        cmd += [all_intcols_str, json_dump, calculate_sep, width, height, strip]
    if plottype == "ft_dist":
        cmd += [whichway, name, id, meancol, nterms, width, height,
                target_rank, target_onto, barcol]
    else:
        ValueError("Wrong plot type. Must be bar, volcano, heatmap, or pca.")
    cmd_string = [str(elem) for elem in cmd]
    subprocess.run(cmd_string, stdout=FNULL, check=True)
    FNULL.close()

